@@ -4,6 +4,7 @@ from collections import defaultdict
 
 from .parser import Parser
 from ...geometry import LabelList, BBox
+from copy import deepcopy
 
 
 class VisualizerUtil:
@@ -132,7 +133,7 @@ class ImageVisualizePipeline(VisualizerUtil):
         self.visualize_result = self.group_media_and_ann()
 
     def group_media_and_ann(self):
-        data_dic = self.data_dic.copy()
+        data_dic = deepcopy(self.data_dic)
         image_dic = data_dic.pop("image")
         image_paths = list(image_dic.keys())
         # 将图像按照路径进行从长到短排序
