@@ -2,6 +2,7 @@ from .box import BBox
 from .label import Label, LabelList
 from .media import ImageMedia
 from .polygon import Polygon, PolygonItem
+from .attrbutes import Attributes
 
 __all__ = [
     "BBox",
@@ -10,4 +11,5 @@ __all__ = [
     "LabelList",
     "Polygon",
     "PolygonItem",
+    "Attributes",
 ]
